"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const api_module_1 = require("./api-module");
class Notification extends api_module_1.default {
    async sendNotification(type, targetUser, message = '', details = {}) {
        const result = await this.postReq(`user/${targetUser}/notification`, {
            type: type,
            message: message,
            details: JSON.stringify(details)
        });
        return result.data;
    }
    get send() {
        return {
            friendRequest: async (targetUser) => {
                return await this.sendNotification('friendrequest', targetUser);
            },
            invite: async (targetUser, worldId, message = '') => {
                return await this.sendNotification('invite', targetUser, message, {
                    worldId: worldId
                });
            },
            /**
             * @deprecated
             */
            halp: async (targetUser, worldId, message = '') => {
                // TODO わからん
                return await this.sendNotification('halp', targetUser, message, {});
            },
            /**
             * @deprecated
             */
            voteToKick: async (targetUser) => {
                // TODO わからん
                return await this.sendNotification('votetokick', targetUser, "", {});
            },
            /**
             * @deprecated
             */
            all: async (targetUser) => {
                // TODO わからん
                return await this.sendNotification('all', targetUser, "", {});
            },
            /**
             * @deprecated
             */
            hidden: async (targetUser) => {
                // TODO わからん
                return await this.sendNotification('hidden', targetUser, "", {});
            },
            /**
             * @deprecated It seems that it can not be used yet.
             */
            async message(targetUser, message) {
                return await this.sendNotification('message', targetUser, message);
            },
        };
    }
    async markAsRead(notificationId) {
        const result = await this.putReq(`auth/user/notifications/${notificationId}/see`);
        return result.data;
    }
    async delete(notificationId) {
        const result = await this.putReq(`auth/user/notifications/${notificationId}/hide`);
        return result.data;
    }
    async getAll() {
        const result = await this.getReq(`auth/user/notifications`);
        return result.data;
    }
}
exports.default = Notification;
